@@ -1,6 +1,5 @@
 context("tmle_shift_orig agrees with Diaz and van der Laan (2012)")
 library(data.table)
-library(rlang)
 set.seed(73294)
 
 ################################################################################
@@ -112,14 +111,16 @@ gn_ext_fitted <- as.data.table(
       gn_out <- gn.0(A = A + shift_value, W = W)
     }
   )
-) %>% set_names(c("downshift", "noshift", "upshift", "upupshift"))
+)
+setnames(gn_ext_fitted, c("downshift", "noshift", "upshift", "upupshift"))
 
 # NOTE: should also use true Q for good measure (truth includes interactions)
 Qn_ext_fitted <- as.data.table(
   lapply(c(0, delta_shift), function(shift_value) {
     Qn_out <- Qn.0(A = A + shift_value, W = W)
   })
-) %>% set_names(c("noshift", "upshift"))
+)
+setnames(Qn_ext_fitted, c("noshift", "upshift"))
 
 # fit TMLE
 tmle_txshift <- txshift(
